==> libgnomedb-1.3.4.tar.bz2: libgnomedb-1.3.4/libgnomedb/gnome-db-sql-console.h <==
/* gnome-db-sql-console.h
 *
 * Copyright (C) 2005 Vivien Malerba
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License as
 * published by the Free Software Foundation; either version 2 of the
 * License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
 * USA
 */

#ifndef __GNOME_DB_SQL_CONSOLE__
#define __GNOME_DB_SQL_CONSOLE__

#include <gtk/gtk.h>
#include "gnome-db-dict.h"

G_BEGIN_DECLS

#define GNOME_DB_SQL_CONSOLE_TYPE          (gnome_db_sql_console_get_type())
#define GNOME_DB_SQL_CONSOLE(obj)          G_TYPE_CHECK_INSTANCE_CAST (obj, gnome_db_sql_console_get_type(), GnomeDbSqlConsole)
#define GNOME_DB_SQL_CONSOLE_CLASS(klass)  G_TYPE_CHECK_CLASS_CAST (klass, gnome_db_sql_console_get_type (), GnomeDbSqlConsoleClass)
#define IS_GNOME_DB_SQL_CONSOLE(obj)       G_TYPE_CHECK_INSTANCE_TYPE (obj, gnome_db_sql_console_get_type ())


typedef struct _GnomeDbSqlConsole      GnomeDbSqlConsole;
typedef struct _GnomeDbSqlConsoleClass GnomeDbSqlConsoleClass;
typedef struct _GnomeDbSqlConsolePriv  GnomeDbSqlConsolePriv;

/* struct for the object's data */
struct _GnomeDbSqlConsole
{
	GtkTextView            object;

	GnomeDbSqlConsolePriv *priv;
};

/* struct for the object's class */
struct _GnomeDbSqlConsoleClass
{
	GtkTextViewClass       parent_class;
};

/* 
 * Generic widget's methods 
*/
GType      gnome_db_sql_console_get_type                 (void);

GtkWidget *gnome_db_sql_console_new                      (GnomeDbDict *dict, const gchar *message);
void       gnome_db_sql_console_clear                    (GnomeDbSqlConsole *console);
void       gnome_db_sql_console_clear_history            (GnomeDbSqlConsole *console);


G_END_DECLS

#endif

==> libgnomedb-1.3.91.tar.bz2: libgnomedb-1.3.91/libgnomedb/gnome-db-sql-console.h <==
/* gnome-db-sql-console.h
 *
 * Copyright (C) 2005 Vivien Malerba
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License as
 * published by the Free Software Foundation; either version 2 of the
 * License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
 * USA
 */

#ifndef __GNOME_DB_SQL_CONSOLE__
#define __GNOME_DB_SQL_CONSOLE__

#include <gtk/gtk.h>
#include "gnome-db-dict.h"

G_BEGIN_DECLS

#define GNOME_DB_TYPE_SQL_CONSOLE          (gnome_db_sql_console_get_type())
#define GNOME_DB_SQL_CONSOLE(obj)          G_TYPE_CHECK_INSTANCE_CAST (obj, gnome_db_sql_console_get_type(), GnomeDbSqlConsole)
#define GNOME_DB_SQL_CONSOLE_CLASS(klass)  G_TYPE_CHECK_CLASS_CAST (klass, gnome_db_sql_console_get_type (), GnomeDbSqlConsoleClass)
#define IS_GNOME_DB_SQL_CONSOLE(obj)       G_TYPE_CHECK_INSTANCE_TYPE (obj, gnome_db_sql_console_get_type ())


typedef struct _GnomeDbSqlConsole      GnomeDbSqlConsole;
typedef struct _GnomeDbSqlConsoleClass GnomeDbSqlConsoleClass;
typedef struct _GnomeDbSqlConsolePriv  GnomeDbSqlConsolePriv;

/* struct for the object's data */
struct _GnomeDbSqlConsole
{
	GtkTextView            object;

	GnomeDbSqlConsolePriv *priv;
};

/* struct for the object's class */
struct _GnomeDbSqlConsoleClass
{
	GtkTextViewClass       parent_class;
};

/* 
 * Generic widget's methods 
*/
GType      gnome_db_sql_console_get_type                 (void);

GtkWidget *gnome_db_sql_console_new                      (GnomeDbDict *dict, const gchar *message);
void       gnome_db_sql_console_clear                    (GnomeDbSqlConsole *console);
void       gnome_db_sql_console_clear_history            (GnomeDbSqlConsole *console);


G_END_DECLS

#endif
